@@ -16,6 +16,13 @@ class SingleScaler:
         self._column = column
         self._pipeline = None
 
+    def __getstate__(self):
+        return {'_column': self._column, '_pipeline': self._pipeline}
+
+    def __setstate__(self, state):
+        for key, value in state.items():
+            setattr(self, key, value)
+
     def fit(self, X):
         # normalizing
         assembler = VectorAssembler(
@@ -40,6 +47,13 @@ class Scaler:
         self._columns = columns
         self._single_scalers = None
 
+    def __getstate__(self):
+        return {'_columns': self._columns, '_single_scalers': self._single_scalers}
+
+    def __setstate__(self, state):
+        for key, value in state.items():
+            setattr(self, key, value)
+
     def fit(self, X):
         if self._columns is not None:
             X = X.select(*self._columns)
